MeshCollection

Struct MeshCollection 

pub struct MeshCollection {
    pub meshes: Vec<TriangleMesh>,
}
Represents a collection of TriangleMesh objects.

Fields

meshes: Vec<TriangleMesh>

Implementations

Source

impl MeshCollection

pub fn new(meshes: Vec<TriangleMesh>) -> Self

Creates a new MeshCollection from a vector of TriangleMeshes

pub fn num_meshes(&self) -> usize

Returns the number of meshes in the collection.

pub fn num_triangles(&self) -> usize

Returns the number of triangles in the collection.

pub fn num_vertices(&self) -> usize

Returns the number of vertices in the collection.

pub fn num_normals(&self) -> usize

Returns the number of normal vectors in the collection.

pub fn triangles(&self) -> impl Iterator<Item = Triangle> + '_

Returns an iterator over all the Triangles in the collection.

pub fn vertices(&self) -> impl Iterator<Item = Vertex> + '_

Returns an iterator over all the Vertex objects in the collection.

pub fn normals(&self) -> impl Iterator<Item = Normal> + '_

Returns an iterator over all the Normals in the collection.

pub fn index_of_first_vertex(&self, mesh_index: usize) -> usize

Returns the index of the first Vertex of a given TriangleMesh in the collection.

Source

impl MeshCollection

pub fn write_stl(&self, path: &str) -> Result<(), Error>

Writes the STL representation of the mesh collection to a file.

pub fn to_stl(&self) -> String

pub fn from_stl(stl_str: &str) -> Result<Self>

Reads an STL file and returns a TriangleMesh.