pub struct BoundingBox<const N: usize> { /* private fields */ }Expand description
A hypercube in N-dimensional space representing a bounding box.
Implementations
Sourceimpl<const N: usize> BoundingBox<N>
impl<const N: usize> BoundingBox<N>
Sourcepub fn new(min: NVector<N>, max: NVector<N>) -> Self
pub fn new(min: NVector<N>, max: NVector<N>) -> Self
Creates a new BoundingBox from a minimum and maximum NVector.
Sourcepub fn min(&self) -> &NVector<N>
pub fn min(&self) -> &NVector<N>
Returns the minimum of the BoundingBox.
Sourcepub fn max(&self) -> &NVector<N>
pub fn max(&self) -> &NVector<N>
Returns the maximum of the BoundingBox.
Sourcepub fn volume(&self) -> f32
pub fn volume(&self) -> f32
Returns the volume of the BoundingBox.
Sourcepub fn center(&self) -> NVector<N>
pub fn center(&self) -> NVector<N>
Returns the center of the BoundingBox.
Sourcepub fn contains(&self, point: &NVector<N>) -> bool
pub fn contains(&self, point: &NVector<N>) -> bool
Determine if an NVector is within the BoundingBox.
Sourcepub fn contains_tensor<B: Backend>(
&self,
points: Tensor<B, 2>,
) -> Tensor<B, 1, Bool>
pub fn contains_tensor<B: Backend>( &self, points: Tensor<B, 2>, ) -> Tensor<B, 1, Bool>
Determine if a set of points are within the BoundingBox.
Sourcepub fn corners(&self) -> impl Iterator<Item = NVector<N>>
pub fn corners(&self) -> impl Iterator<Item = NVector<N>>
Returns the corners of the BoundingBox as an iterator of NVectors.
Sourcepub fn sample(&self, rng: &mut impl Rng) -> NVector<N>
pub fn sample(&self, rng: &mut impl Rng) -> NVector<N>
Sample a random point within the BoundingBox.
Sourcepub fn sample_on_device<B: Backend>(
&self,
num_samples: usize,
rng: &mut impl Rng,
device: &B::Device,
) -> Tensor<B, 2, Float>
pub fn sample_on_device<B: Backend>( &self, num_samples: usize, rng: &mut impl Rng, device: &B::Device, ) -> Tensor<B, 2, Float>
Sample many random points within the BoundingBox on a given device.
Sourcepub fn split(&self) -> (BoundingBox<N>, BoundingBox<N>)
pub fn split(&self) -> (BoundingBox<N>, BoundingBox<N>)
Split a BoundingBox into two equally-sized BoundingBoxes along the longest axis
Sourcepub fn multisplit(&self, depth: usize) -> Vec<BoundingBox<N>>
pub fn multisplit(&self, depth: usize) -> Vec<BoundingBox<N>>
Subdivide a BoundingBox into a set of BoundingBoxes
This makes 2^(N * depth) leaf BoundingBoxes.
Sourcepub fn point_in_bounds(&self, point: &NVector<N>) -> bool
pub fn point_in_bounds(&self, point: &NVector<N>) -> bool
Determine if a point is within the BoundingBox.
Sourcepub fn points_in_bounds<B: Backend>(
&self,
points: Tensor<B, 2, Float>,
) -> Tensor<B, 1, Bool>
pub fn points_in_bounds<B: Backend>( &self, points: Tensor<B, 2, Float>, ) -> Tensor<B, 1, Bool>
Determine if a set of points are within the BoundingBox.