pub struct MeshCollection {
pub meshes: Vec<TriangleMesh>,
}Expand description
Represents a collection of TriangleMesh objects.
Fields
meshes: Vec<TriangleMesh>Implementations
Sourceimpl MeshCollection
impl MeshCollection
Sourcepub fn new(meshes: Vec<TriangleMesh>) -> Self
pub fn new(meshes: Vec<TriangleMesh>) -> Self
Creates a new MeshCollection from a vector of TriangleMeshes
Sourcepub fn num_meshes(&self) -> usize
pub fn num_meshes(&self) -> usize
Returns the number of meshes in the collection.
Sourcepub fn num_triangles(&self) -> usize
pub fn num_triangles(&self) -> usize
Returns the number of triangles in the collection.
Sourcepub fn num_vertices(&self) -> usize
pub fn num_vertices(&self) -> usize
Returns the number of vertices in the collection.
Sourcepub fn num_normals(&self) -> usize
pub fn num_normals(&self) -> usize
Returns the number of normal vectors in the collection.
Sourcepub fn triangles(&self) -> impl Iterator<Item = Triangle> + '_
pub fn triangles(&self) -> impl Iterator<Item = Triangle> + '_
Returns an iterator over all the Triangles in the collection.
Sourcepub fn vertices(&self) -> impl Iterator<Item = Vertex> + '_
pub fn vertices(&self) -> impl Iterator<Item = Vertex> + '_
Returns an iterator over all the Vertex objects in the collection.
Sourcepub fn normals(&self) -> impl Iterator<Item = Normal> + '_
pub fn normals(&self) -> impl Iterator<Item = Normal> + '_
Returns an iterator over all the Normals in the collection.
Sourcepub fn index_of_first_vertex(&self, mesh_index: usize) -> usize
pub fn index_of_first_vertex(&self, mesh_index: usize) -> usize
Returns the index of the first Vertex of a given TriangleMesh in the collection.